Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(399)

Unified Diff: chrome/browser/dom_ui/chrome_url_data_manager.cc

Issue 2008007: Replace about:net-internals with the javascript-based frontend.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: improve a comment Created 10 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/browser_about_handler.cc ('k') | chrome/browser/dom_ui/net_internals_ui.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/dom_ui/chrome_url_data_manager.cc
===================================================================
--- chrome/browser/dom_ui/chrome_url_data_manager.cc (revision 46824)
+++ chrome/browser/dom_ui/chrome_url_data_manager.cc (working copy)
@@ -20,7 +20,7 @@
#include "chrome/browser/browser_process.h"
#include "chrome/browser/chrome_thread.h"
#include "chrome/browser/net/chrome_url_request_context.h"
-#include "chrome/browser/net/view_net_internals_job_factory.h"
+#include "chrome/browser/net/view_http_cache_job_factory.h"
#include "chrome/common/chrome_paths.h"
#include "chrome/common/ref_counted_util.h"
#include "chrome/common/url_constants.h"
@@ -325,9 +325,9 @@
if (ChromeURLDataManager::URLToFilePath(request->url(), &path))
return new URLRequestChromeFileJob(request, path);
- // Next check for chrome://net-internals/, which uses its own job type.
- if (ViewNetInternalsJobFactory::IsSupportedURL(request->url()))
- return ViewNetInternalsJobFactory::CreateJobForRequest(request);
+ // Next check for chrome://view-http-cache/*, which uses its own job type.
+ if (ViewHttpCacheJobFactory::IsSupportedURL(request->url()))
+ return ViewHttpCacheJobFactory::CreateJobForRequest(request);
// Next check for chrome://appcache-internals/, which uses its own job type.
if (ViewAppCacheInternalsJobFactory::IsSupportedURL(request->url()))
« no previous file with comments | « chrome/browser/browser_about_handler.cc ('k') | chrome/browser/dom_ui/net_internals_ui.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698